@@ -39,13 +39,6 @@ export default {
         "type": "string"
       },
       "description": "Plugin API and other plugins required for this plugin to work."
-    },
-    "disableStaticPlugins": {
-      "type": "array",
-      "items": {
-        "type": "string"
-      },
-      "description": "Disable the given static plugins when this plugin gets loaded."
     }
   },
   "required": [
